@@ -1,4 +1,4 @@
-//@line 43 "/usr/obj/i386/thunderbird-5.0/comm-miramar/mail/components/addrbook/content/addressbook.js"
+//@line 43 "/usr/obj/thunderbird-9.0.1/comm-release/mail/components/addrbook/content/addressbook.js"
 
 // Ensure the activity modules are loaded for this window.
 Components.utils.import("resource:///modules/activity/activityModules.js");
@@ -12,7 +12,6 @@ var cvPrefs = 0;
 var gSearchTimer = null;
 var gStatusText = null;
 var gQueryURIFormat = null;
-var gSearchInput;
 var gCardViewBox;
 var gCardViewBoxEmail1;
 var gPreviousDirTreeIndex = -1;
@@ -141,8 +140,6 @@ function OnLoadAddressBook()
 
 function delayedOnLoadAddressBook()
 {
-  gSearchInput = document.getElementById("peopleSearchInput");
-
   verifyAccounts(null, false);   // this will do migration, if we need to.
 
   InitCommonJS();
@@ -428,7 +425,8 @@ function SetStatusText(total)
   try {
     var statusText;
 
-    if (gSearchInput && gSearchInput.value) {
+    var searchInput = document.getElementById("peopleSearchInput");
+    if (searchInput && searchInput.value) {
       if (total == 0)
         statusText = gAddressBookBundle.getString("noMatchFound");
       else
@@ -492,10 +490,11 @@ function onEnterInSearchBar()
    already has a query, like
    moz-abldapdirectory://nsdirectory.netscape.com:389/ou=People,dc=netscape,dc=com?(or(Department,=,Applications))
   */
-  if (gSearchInput.value != "") {
+  var searchInput = document.getElementById("peopleSearchInput");
+  if (searchInput && searchInput.value != "") {
     // replace all instances of @V with the escaped version
     // of what the user typed in the quick search text input
-    searchURI += gQueryURIFormat.replace(/@V/g, encodeURIComponent(gSearchInput.value));
+    searchURI += gQueryURIFormat.replace(/@V/g, encodeURIComponent(searchInput.value));
   }
 
   SetAbView(searchURI);
@@ -513,6 +512,7 @@ function SwitchPaneFocus(event)
   var cardViewBoxEmail1 = GetCardViewBoxEmail1();
   var searchBox         = document.getElementById('search-container');
   var dirTree           = GetDirTree();
+  var searchInput       = document.getElementById('peopleSearchInput');
 
   if (event && event.shiftKey)
   {
@@ -543,8 +543,8 @@ function SwitchPaneFocus(event)
     }
     else if (focusedElement != dirTree && !IsDirPaneCollapsed())
       dirTree.focus();
-    else if (searchBox)
-      gSearchInput.focus();
+    else if (searchBox && searchInput)
+      searchInput.focus();
     else
       gAbResultsTree.focus();
   }
