@@ -1,4 +1,4 @@
-//@line 39 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/base/content/mailCore.js"
+//@line 39 "/usr/obj/thunderbird-9.0.1/comm-release/mail/base/content/mailCore.js"
 
 /*
  * Core mail routines used by all of the major mail windows (address book, 3-pane, compose and stand alone message window).
@@ -221,8 +221,6 @@ function MailToolboxCustomizeDone(aEvent, customizePopupId)
         popup.removeChild(popup.lastChild);
     }
   }
-  UpdateJunkButton();
-  UpdateReplyButtons();
 }
 
 function onViewToolbarCommand(aEvent, toolboxId)
@@ -231,8 +229,12 @@ function onViewToolbarCommand(aEvent, toolboxId)
   var index = aEvent.originalTarget.getAttribute("toolbarindex");
   var toolbar = toolbox.childNodes[index];
 
-  toolbar.collapsed = aEvent.originalTarget.getAttribute("checked") != "true";
-  document.persist(toolbar.id, "collapsed");
+  var hidingAttribute = toolbar.getAttribute("type") == "menubar" ?
+                        "autohide" : "collapsed";
+
+  toolbar.setAttribute(hidingAttribute,
+                       aEvent.originalTarget.getAttribute("checked") != "true");
+  document.persist(toolbar.id, hidingAttribute);
 }
 
 function onViewToolbarsPopupShowing(aEvent, toolboxId)
@@ -252,14 +254,15 @@ function onViewToolbarsPopupShowing(aEvent, toolboxId)
   for (var i = 0; i < toolbox.childNodes.length; ++i) {
     var toolbar = toolbox.childNodes[i];
     var toolbarName = toolbar.getAttribute("toolbarname");
-    var type = toolbar.getAttribute("type");
-    if (toolbarName && type != "menubar") {
-      var menuItem = document.createElement("menuitem");
+    if (toolbarName) {
+      let menuItem = document.createElement("menuitem");
+      let hidingAttribute = toolbar.getAttribute("type") == "menubar" ?
+                            "autohide" : "collapsed";
       menuItem.setAttribute("toolbarindex", i);
       menuItem.setAttribute("type", "checkbox");
       menuItem.setAttribute("label", toolbarName);
       menuItem.setAttribute("accesskey", toolbar.getAttribute("accesskey"));
-      menuItem.setAttribute("checked", toolbar.getAttribute("collapsed") != "true");
+      menuItem.setAttribute("checked", toolbar.getAttribute(hidingAttribute) != "true");
       popup.insertBefore(menuItem, firstMenuItem);
       menuItem.addEventListener("command",
         function(aEvent) { onViewToolbarCommand(aEvent, toolboxId); }, false);
@@ -437,10 +440,9 @@ function openAboutDialog()
     return;
   }
 
-//@line 480 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/base/content/mailCore.js"
-  // XXX Should have dependent as well?
-  var features = "chrome,centerscreen,resizable=no";
-//@line 483 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/base/content/mailCore.js"
+//@line 485 "/usr/obj/thunderbird-9.0.1/comm-release/mail/base/content/mailCore.js"
+  var features = "chrome,centerscreen,dependent,dialog=no";
+//@line 487 "/usr/obj/thunderbird-9.0.1/comm-release/mail/base/content/mailCore.js"
   window.openDialog("chrome://messenger/content/aboutDialog.xul", "About", features);
 }
 
@@ -501,13 +503,13 @@ function safeModeRestart()
   }
 }
 
-//@line 546 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/base/content/mailCore.js"
+//@line 550 "/usr/obj/thunderbird-9.0.1/comm-release/mail/base/content/mailCore.js"
 
 function getMostRecentMailWindow() {
   let wm = Cc["@mozilla.org/appshell/window-mediator;1"]
              .getService(Components.interfaces.nsIWindowMediator);
 
-//@line 552 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/base/content/mailCore.js"
+//@line 556 "/usr/obj/thunderbird-9.0.1/comm-release/mail/base/content/mailCore.js"
   let win = wm.getMostRecentWindow("mail:3pane", true);
 
   // if we're lucky, this isn't a popup, and we can just return this
@@ -521,11 +523,29 @@ function getMostRecentMailWindow() {
         win = nextWin;
     }
   }
-//@line 578 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/base/content/mailCore.js"
+//@line 582 "/usr/obj/thunderbird-9.0.1/comm-release/mail/base/content/mailCore.js"
 
   return win;
 }
 
+/**
+ * Create a sanitized display name for an attachment in order to help prevent
+ * people from hiding malicious extensions behind a run of spaces, etc. To do
+ * this, we strip leading/trailing whitespace and collapse long runs of either
+ * whitespace or identical characters. Windows especially will drop trailing
+ * dots and whitespace from filename extensions.
+ *
+ * @param aAttachment the AttachmentInfo object
+ * @return a sanitized display name for the attachment
+ */
+function SanitizeAttachmentDisplayName(aAttachment)
+{
+  let displayName = aAttachment.name.trim();
+  return displayName.replace(/\s+/g, " ")
+//@line 603 "/usr/obj/thunderbird-9.0.1/comm-release/mail/base/content/mailCore.js"
+                    .replace(/(.)\1{9,}/g, "$1…$1");
+}
+
 /**
  * Create a TransferData object for a message attachment, either from the
  * message reader or the composer.
@@ -609,7 +629,8 @@ nsFlavorDataProvider.prototype =
       // call our code for saving attachments
       if (attachment)
       {
-        var destFilePath = messenger.saveAttachmentToFolder(attachment.contentType, attachment.url, encodeURIComponent(attachment.displayName), attachment.uri, destDirectory);
+        var name = attachment.name || attachment.displayName;
+        var destFilePath = messenger.saveAttachmentToFolder(attachment.contentType, attachment.url, encodeURIComponent(name), attachment.uri, destDirectory);
         aData.value = destFilePath.QueryInterface(Components.interfaces.nsISupports);
         aDataLen.value = 4;
       }
