@@ -51,9 +51,6 @@ var msgWindow;
 var msgComposeService;
 var accountManager;
 
-var gMessengerBundle;
-var gBrandBundle;
-
 var gContextMenu;
 var gMailWindowLog = Log4Moz.getConfiguredLogger("mailWindow", Log4Moz.Level.Debug, Log4Moz.Level.Debug, Log4Moz.Level.Debug);
 
@@ -131,9 +128,6 @@ function CreateMailWindowGlobals()
 
   accountManager = Components.classes["@mozilla.org/messenger/account-manager;1"].getService(Components.interfaces.nsIMsgAccountManager);
 
-  gMessengerBundle = document.getElementById("bundle_messenger");
-  gBrandBundle = document.getElementById("bundle_brand");
-
   msgWindow.notificationCallbacks = new BadCertHandler();
 }
 
@@ -465,25 +459,6 @@ nsMsgWindowCommands.prototype =
   }
 }
 
-/**
- * @returns the pref name to use for fetching the start page url. Every time the application version changes,
- * return "mailnews.start_page.override_url". If this is the first time the application has been
- * launched, return "mailnews.start_page.welcome_url". Otherwise return "mailnews.start_page.url".
- */
-function startPageUrlPref()
-{
-  var prefForStartPageUrl = "mailnews.start_page.url";
-  var savedVersion = null;
-  try {
-    savedVersion = pref.getCharPref("mailnews.start_page_override.mstone");
-  } catch (ex) {}
-
-  if (!savedVersion && savedVersion != "ignore")
-    prefForStartPageUrl = "mailnews.start_page.welcome_url";
-
-  return prefForStartPageUrl;
-}
-
 /**
  * Loads the mail start page.
  */
@@ -497,7 +472,7 @@ function loadStartPage(aForce)
   gMessageNotificationBar.clearMsgNotifications();
   let startpage = Components.classes["@mozilla.org/toolkit/URLFormatterService;1"]
                             .getService(Components.interfaces.nsIURLFormatter)
-                            .formatURLPref(startPageUrlPref());
+                            .formatURLPref("mailnews.start_page.url");
   if (startpage)
   {
     try {
@@ -539,7 +514,7 @@ function getNotificationBox(aWindow) {
                       tabInfo[i].mode.tabType.getBrowser;
     if (browserFunc) {
       var possBrowser = browserFunc.call(tabInfo[i].mode.tabType, tabInfo[i]);
-      if (possBrowser && possBrowser.contentWindow == aWindow)
+      if (possBrowser && possBrowser.contentWindow == aWindow && possBrowser.parentNode.tagName == "notificationbox")
         return possBrowser.parentNode;
     }
   }
