@@ -36,28 +36,28 @@
  *
  * ***** END LICENSE BLOCK ***** */
 
-//@line 40 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 40 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
-//@line 46 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 46 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
-pref("general.useragent.extra.thunderbird", "Thunderbird/5.0");
+pref("general.useragent.extra.thunderbird", "Thunderbird/9.0.1");
 
 pref("general.useragent.locale", "en-US");
 pref("general.skins.selectedSkin", "classic/1.0");
 
-//@line 56 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 56 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 pref("mail.rights.version", 0);
 
 // Don't show the about:rights notification in debug or non-official builds.
-//@line 66 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 66 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 // gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
 // want to disable it so people can see where they are dragging things.
 // (Stock gtk drag icons will be used instead.)
-//@line 71 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 71 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 pref("nglayout.enable_drag_images", false);
-//@line 73 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 73 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 // App-specific update preferences
 
@@ -123,6 +123,11 @@ pref("extensions.logging.enabled", false);
 
 pref("extensions.update.autoUpdateDefault", true);
 
+// Disable add-ons installed into the shared user and shared system areas by
+// default. This does not include the application directory. See the SCOPE
+// constants in AddonManager.jsm for values to use here
+pref("extensions.autoDisableScopes", 15);
+
 // Preferences for AMO integration
 pref("extensions.getAddons.cache.enabled", true);
 pref("extensions.getAddons.maxResults", 15);
@@ -135,7 +140,8 @@ pref("extensions.webservice.discoverURL", "https://services.addons.mozilla.org/%
 pref("extensions.blocklist.enabled", true);
 pref("extensions.blocklist.interval", 86400);
 pref("extensions.blocklist.url", "https://addons.mozilla.org/blocklist/3/%APP_ID%/%APP_VERSION%/%PRODUCT%/%BUILD_ID%/%BUILD_TARGET%/%LOCALE%/%CHANNEL%/%OS_VERSION%/%DISTRIBUTION%/%DISTRIBUTION_VERSION%/%PING_COUNT%/%TOTAL_PING_COUNT%/%DAYS_SINCE_LAST_PING%/");
-pref("extensions.blocklist.detailsURL", "https://www.mozilla.com/%LOCALE%/blocklist/");
+pref("extensions.blocklist.detailsURL", "https://addons.mozilla.org/%LOCALE%/%APP%/blocked/");
+pref("extensions.blocklist.itemURL", "https://addons.mozilla.org/%LOCALE%/%APP%/blocked/%blockID%");
 
 // Enables some extra Extension System Logging (can reduce performance) 
 pref("extensions.logging.enabled", false); 
@@ -180,11 +186,11 @@ pref("mail.last_msg_movecopy_target_uri", "");
 // last move or copy operation was a move
 pref("mail.last_msg_movecopy_was_move", true);
 
-//@line 198 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 204 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.instantApply", true);
-//@line 203 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 209 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 pref("browser.preferences.animateFadeIn", false);
-//@line 205 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 211 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 pref("browser.download.show_plugins_in_list", false);
 pref("browser.download.hide_plugins_without_extensions", true);
@@ -209,7 +215,7 @@ pref("mail.ui.show.migration.on.upgrade", true);
 pref("mail.showCondensedAddresses", true); // show the friendly display name for people I know
 
 // hidden pref for changing how we present attachments in the message pane
-pref("mailnews.attachments.display.largeView", false);
+pref("mailnews.attachments.display.view", 0);
 pref("mail.pane_config.dynamic",            0);
 pref("mailnews.reuse_thread_window2",     true);
 pref("editor.singleLine.pasteNewlines", 4);  // substitute commas for new lines in single line text boxes
@@ -260,9 +266,9 @@ pref("offline.send.unsent_messages",            0);
 // 2 Never synchronize the offline store when going offline
 pref("offline.download.download_messages",  0);
 
-//@line 281 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 287 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 pref("offline.autoDetect", false);
-//@line 287 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 293 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 // Expose only select protocol handlers. All others should go
 // through the external protocol handler route.
@@ -301,6 +307,9 @@ pref("general.config.obscure_value", 0); // for MCD .cfg files
 pref("browser.display.auto_quality_min_font_size", 0);
 
 pref("view_source.syntax_highlight", false);
+
+pref("toolkit.telemetry.infoURL", "http://www.mozilla.org/thunderbird/legal/privacy/#telemetry");
+
 /////////////////////////////////////////////////////////////////
 // End core all.js pref overrides
 ///////////////////////////////////////////////////////////////// 
@@ -405,15 +414,15 @@ pref("mail.tabs.closeButtons", 1);
 pref("breakpad.reportURL", "http://crash-stats.mozilla.com/report/index/");
 
 // OS Integrated Search and Indexing
-//@line 438 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 447 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 // -- Windows Search/Spotlight logging options
-//@line 453 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 462 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 // Whether to use a panel that looks like an OS X sheet for customization
-//@line 458 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 467 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 pref("toolbar.customization.usesheet", false);
-//@line 460 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 469 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 // Check for missing attachments?
 pref("mail.compose.attachment_reminder", true);
@@ -461,13 +470,13 @@ pref("font.default.x-baltic", "sans-serif");
 pref("font.default.el", "sans-serif");
 pref("font.default.tr", "sans-serif");
 
-//@line 557 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 566 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 // Since different versions of Windows need different settings, we'll handle
 // this in mailMigrator.js.
 
 // Linux, in other words.  Other OSes may wish to override.
-//@line 563 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 572 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 // The font.name-list fallback is defined in case font.name isn't
 // present -- e.g. in case a profile that's been used on Windows Vista or above
 // is used on Linux.
@@ -498,7 +507,7 @@ pref("font.name-list.monospace.el", "monospace");
 pref("font.name-list.serif.tr", "serif");
 pref("font.name-list.sans-serif.tr", "sans-serif");
 pref("font.name-list.monospace.tr", "monospace");
-//@line 594 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
+//@line 603 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
 
 pref("mail.font.windows.version", 0);
 
@@ -540,7 +549,10 @@ pref("places.history.enabled", false);
 // allowed cache size it will at most use the size of the database file.
 // Changes to this value are effective after an application restart.
 // Acceptable values are between 0 and 50.
-pref("places.database.cache_to_memory_percentage", 6);
+// In Thunderbird, we're not exercising places much, so it makes sense to make
+// it use a lower percentage of the cache. Plus, we have another more important
+// sqlite database (gloda) that deserves to use cache.
+pref("places.database.cache_to_memory_percentage", 1);
 
 // the (maximum) number of the recent visits to sample
 // when calculating frecency
@@ -578,5 +590,37 @@ pref("browser.urlbar.restrict.openpage", "%");
 
 // The default for this pref reflects whether the build is capable of IPC.
 // (Turning it on in a no-IPC build will have no effect.)
-//@line 684 "/usr/obj/ports/thunderbird-5.0/comm-miramar/mail/app/profile/all-thunderbird.js"
-pref("dom.ipc.plugins.enabled", false);
+//@line 694 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
+pref("dom.ipc.plugins.enabled", true);
+//@line 696 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
+
+// This pref governs whether we attempt to work around problems caused by
+// plugins using OS calls to manipulate the cursor while running out-of-
+// process.  These workarounds all involve intercepting (hooking) certain
+// OS calls in the plugin process, then arranging to make certain OS calls
+// in the browser process.  Eventually plugins will be required to use the
+// NPAPI to manipulate the cursor, and these workarounds will be removed.
+// See bug 621117.
+//@line 707 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
+
+// plugin finder service url
+pref("pfs.datasource.url", "https://pfs.mozilla.org/plugins/PluginFinderService.
+php?mimetype=%PLUGIN_MIMETYPE%&appID=%APP_ID%&appVersion=%APP_VERSION%&clientOS=
+%CLIENT_OS%&chromeLocale=%CHROME_LOCALE%&appRelease=%APP_RELEASE%");
+
+// By default we show an infobar message when pages require plugins the user has
+// not installed, or are outdated.
+pref("plugins.hide_infobar_for_missing_plugin", false);
+pref("plugins.hide_infobar_for_outdated_plugin", false);
+
+//@line 722 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
+
+pref("plugins.update.url", "https://www.mozilla.com/%LOCALE%/plugincheck/");
+pref("plugins.update.notifyUser", false);
+pref("plugins.crash.supportUrl", "https://live.mozillamessaging.com/%APP%/plugin-crashed?locale=%LOCALE%&version=%VERSION%&os=%OS%&buildid=%APPBUILDID%");
+
+// Windows taskbar support
+//@line 732 "/usr/obj/ports/thunderbird-9.0.1/comm-release/mail/app/profile/all-thunderbird.js"
+
+// Disable hardware accelerated layers
+pref("layers.acceleration.disabled", true);
