@@ -124,6 +124,8 @@ pref("mail.imap.expunge_after_delete",      false);
 pref("mail.imap.check_deleted_before_expunge", false);
 pref("mail.imap.expunge_option",            0);
 pref("mail.imap.expunge_threshold_number",  20);
+pref("mail.imap.hdr_chunk_size", 200);
+
 // if true, we assume that a user access a folder in the other users namespace
 // is acting as a delegate for that folder, and wishes to use the other users
 // identity when acting on messages in other users folders.
@@ -148,7 +150,7 @@ pref("mail.file_attach_binary",             false);
 pref("mail.show_headers",                   1); // some
 pref("mail.pane_config.dynamic",            0);
 pref("mail.addr_book.mapit_url.format", "chrome://messenger-region/locale/region.properties");
-//@line 160 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 162 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 
 // the format for "mail.addr_book.quicksearchquery.format" is:
 // @V == the escaped value typed in the quick search bar in the addressbook
@@ -316,7 +318,7 @@ pref("mailnews.customDBHeaders", "");
 // close standalone message window when deleting the displayed message
 pref("mail.close_message_window.on_delete", false);
 
-//@line 330 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 332 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 
 pref("mailnews.open_window_warning", 10); // warn user if they attempt to open more than this many messages at once
 
@@ -374,7 +376,7 @@ pref("mail.identity.default.headers", "");
 
 // by default, only collect addresses the user sends to (outgoing)
 // incoming is all spam anyways
-//@line 391 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 393 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 pref("mail.collect_email_address_outgoing", true);
 
 // by default, use the Collected Addressbook for collection
@@ -510,7 +512,8 @@ pref("mail.send_struct", false);   // HTML->HTML *bold* etc. during Send; ditto
 pref("mailnews.display.date_senders_timezone", false);
 // For the next 4 prefs, see <http://www.bucksch.org/1/projects/mozilla/108153>
 pref("mailnews.display.prefer_plaintext", false);  // Ignore HTML parts in multipart/alternative
-pref("mailnews.display.html_as", 0);  // How to display HTML parts. 0 = Render the sender's HTML; 1 = HTML->TXT->HTML; 2 = Show HTML source; 3 = Sanitize HTML
+pref("mailnews.display.html_as", 0);  // How to display HTML/MIME parts. 0 = Render the sender's HTML; 1 = HTML->TXT->HTML; 2 = Show HTML source; 3 = Sanitize HTML; 4 = Show all body parts
+pref("mailnews.display.show_all_body_parts_menu", false); // Whether the View > Message body as > All body parts menu item is available
 pref("mailnews.display.html_sanitizer.allowed_tags", "html head title body p br div(lang,title) h1 h2 h3 h4 h5 h6 ul(type,compact) ol(type,compact,start) li(type,value) dl dt dd blockquote(type,cite) pre noscript noframes strong em sub sup span(lang,title) acronym(title) abbr(title) del(title,cite,datetime) ins(title,cite,datetime) q(cite) a(href,name,title) img(alt,title,longdesc,src) base(href) area(alt) applet(alt) object(alt) var samp dfn address kbd code cite s strike tt b i table(align) caption tr(align,valign) td(rowspan,colspan,align,valign) th(rowspan,colspan,align,valign) wbr");
 pref("mailnews.display.disallow_mime_handlers", 0);  /* Let only a few classes process incoming data. This protects from bugs (e.g. buffer overflows) and from security loopholes (e.g. allowing unchecked HTML in some obscure classes, although the user has html_as > 0).
 This option is mainly for the UI of html_as.
@@ -616,7 +619,7 @@ pref("mail.biff.animate_dock_icon", false);
 // add jitter to biff interval
 pref("mail.biff.add_interval_jitter", true);
 
-//@line 636 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 639 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 
 // If true, the number used in the Mac OS X dock notification will be the
 // the number of "new" messages, as per the classic Thunderbird definition.
@@ -643,10 +646,10 @@ pref("mailnews.ui.junk.manualMarkAsJunkMarksRead", true);
 pref("mail.ui.folderpane.version", 1);
 
 // for manual upgrades of certain UI features.
-//@line 665 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 668 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 // Thunderbird uses this pref in msgMail3PaneWindow.js for bad reasons.
 pref("mailnews.ui.threadpane.version", 7);
-//@line 668 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 671 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 // for manual upgrades of certain UI features.
 // 1 -> 2 is for the ab results pane tree landing
 // to hide the non default columns in the addressbook dialog
@@ -731,16 +734,16 @@ pref("mailnews.import.text.skipfirstrecord", true);
 // automatically scale attached images that are displayed inline
 pref("mail.enable_automatic_image_resizing", true);
 
-//@line 766 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 769 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 
 // gtk2 (*nix) lacks transparent/translucent drag support (bug 376238), so we
 // want to disable it so people can see where they are dragging things.
 // (Stock gtk drag icons will be used instead.)
-//@line 771 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 774 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 pref("nglayout.enable_drag_images", false);
-//@line 773 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 776 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 
-//@line 777 "/usr/ports/pobj/thunderbird-5.0/comm-miramar/mailnews/mailnews.js"
+//@line 780 "/usr/obj/thunderbird-9.0.1/comm-release/mailnews/mailnews.js"
 
 // For the Empty Junk/Trash confirmation dialogs.
 pref("mailnews.emptyJunk.dontAskAgain", false);
