@@ -1,4 +1,6 @@
-//@line 37 "/usr/obj/i386/thunderbird-5.0/comm-miramar/mozilla/toolkit/mozapps/extensions/content/eula.js"
+//@line 37 "/usr/ports/pobj/thunderbird-9.0.1/comm-release/mozilla/toolkit/mozapps/extensions/content/eula.js"
+
+"use strict";
 
 function Startup() {
   var bundle = document.getElementById("extensionsStrings");
